@@ -37,11 +37,25 @@ class JSONField(Field):
 
     def check(self, **kwargs):
         errors = super().check(**kwargs)
+        errors.extend(self._check_deprecated())
         errors.extend(self._check_default())
         errors.extend(self._check_mysql_version())
         errors.extend(self._check_json_encoder_decoder())
         return errors
 
+    def _check_deprecated(self):
+        return [
+            checks.Warning(
+                "django_mysql.models.JSONField is deprecated.",
+                hint=(
+                    "Use django.db.models.JSONField or "
+                    + "django-jsonfield-backport instead."
+                ),
+                obj=self,
+                id="django_mysql.W004",
+            )
+        ]
+
     def _check_default(self):
         errors = []
         if isinstance(self.default, (list, dict)):
@@ -69,14 +83,14 @@ class JSONField(Field):
     def _check_mysql_version(self):
         errors = []
 
-        any_conn_works = False
-        for _alias, conn in mysql_connections():
-            if (
+        any_conn_works = any(
+            (
                 hasattr(conn, "mysql_version")
                 and not connection_is_mariadb(conn)
                 and conn.mysql_version >= (5, 7)
-            ):
-                any_conn_works = True
+            )
+            for _alias, conn in mysql_connections()
+        )
 
         if not any_conn_works:
             errors.append(
