@@ -1,7 +1,6 @@
 import queue
 from threading import Thread
 
-import django
 import pytest
 from django.db import OperationalError, connection, connections
 from django.db.transaction import TransactionManagementError, atomic
@@ -22,10 +21,7 @@ from tests.testapp.models import (
 
 class LockTests(TestCase):
 
-    if django.VERSION >= (2, 2):
-        databases = ["default", "other"]
-    else:
-        multi_db = True
+    databases = ["default", "other"]
 
     @classmethod
     def setUpClass(cls):
@@ -222,10 +218,7 @@ class LockTests(TestCase):
 
 class TableLockTests(TransactionTestCase):
 
-    if django.VERSION >= (2, 2):
-        databases = ["default", "other"]
-    else:
-        multi_db = True
+    databases = ["default", "other"]
 
     def tearDown(self):
         Alphabet.objects.all().delete()
