@@ -1,4 +1,3 @@
-import django
 import pytest
 from django.db import connections
 from django.test import TestCase
@@ -22,10 +21,7 @@ class OverrideVarsMethodTest(TestCase):
 @override_mysql_variables(TIMESTAMP=123)
 class OverrideVarsClassTest(OverrideVarsMethodTest):
 
-    if django.VERSION >= (2, 2):
-        databases = ["default", "other"]
-    else:
-        multi_db = True
+    databases = ["default", "other"]
 
     def test_class_decorator(self):
         self.check_timestamp(123)
